#-----------------------------------------------------------------------------
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get ride of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
## End of Header: General Commands ##
#----------------------------------------

#
#
#	Pymol Script for visualizing a peptide bond
#	Loren Williams
#
#
#
run ./files/draw_plane_cgo.py
load ./files/alpha_helix.pdb

create peptide, resi 66-69
h_add peptide and name N
alter (name H0*),name='H'
remove not name C+N+O+CA+CB+H
hide everything, peptide
show stick, peptide



label name CA, "CA"
label name C, "C'"
label name O, "O"
label name N, "N"
label name CB, "CB"
label name H02, "H"

set label_size, 25
set label_font_id, 7

angle angle1, resi 67 and name O, resi 67 and name C, resi 68 and name N
angle angle2, resi 67 and name CA, resi 67 and name C, resi 67 and name O
angle angle3, resi 67 and name CA, resi 67 and name C, resi 68 and name N

angle angle4, resi 67 and name C, resi 68 and name N, resi 68 and name H
angle angle5, resi 67 and name C, resi 68 and name N, resi 68 and name CA
angle angle6, resi 68 and name H, resi 68 and name N, resi 68 and name CA
color black, angle1
color black, angle2
color black, angle3
color blue, angle4
color blue, angle5
color blue, angle6

set label_size, 15, a*
set angle_size, .5, angle1
set angle_size, .5, angle2
set angle_size, .47, angle3
set angle_size, .6, angle4
set angle_size, .48, angle5
set angle_size, .65, angle6

distance dist_C-N, resi 67 and name C, resi 68 and name N
set label_color, deepteal, dist*
set label_size, 22.0, dist*

distance dist_N-H, resi 68 and name N, resi 68 and name H
set label_color, deepteal, dist*
set label_size, 22.0, dist*

distance dist_N-CA, resi 68 and name N, resi 68 and name CA
set label_color, deepteal, dist*
set label_size, 22.0, dist*

distance dist_C-O, resi 67 and name C, resi 67 and name O
set label_color, deepteal, dist*
set label_size, 22.0, dist*

distance dist_C-CA, resi 67 and name C, resi 67 and name CA
set label_color, deepteal, dist*
set label_size, 22.0, dist*

python
import sys
sys.path.append('./files/')
from draw_plane_cgo import *

for i in range (67, 68):
	plnme = "plane" + str(i-58)
	st1= 'resi ' + str(i) + ' and name CA'
	st2= 'resi ' + str(i) + ' and name O'
	st3= 'resi ' + str(i+1) + ' and name H'
	st4= 'resi ' + str(i+1) + ' and name CA'
	cmd.select("st1", st1)
	cmd.select("st2", st2)
	cmd.select("st3", st3)
	cmd.select("st4", st4)
	cstr = ''
	ccode = i%3
	if ccode == 1:
		cstr = "(255,0,255)"
	elif ccode == 2:
		cstr = "(255,255,0)"
	else:
		cstr = "(0,255,255)"
	draw_plane(plnme, "st1", "st2", "st3", "st4",cstr)
python end
set cgo_transparency, 0.6

hide line, peptide
show stick, peptide
set stick_radius, 0.14

color wheat, name C*
color gray90, name H*
color red, name O*
color blue, name N*

delete st1
delete st2
delete st3
delete st4

delete alpha_helix
enable peptide

set_view (\
     0.765668631,   -0.504397929,    0.399166733,\
    -0.029229833,   -0.647200704,   -0.761757076,\
     0.642572045,    0.571585774,   -0.510286927,\
    -0.000080307,   -0.000232124,   -9.904445648,\
   -55.468833923,  -38.383533478,  -24.973466873,\
     8.338195801,   11.463378906,  -20.000000000 )
### cut above here and paste into script ### 